Exception: Unbounded::InfiniteEnumerator

Inherits:
TypeError
  • Object
show all
Defined in:
lib/unbounded/infinite_enumerator.rb

Overview

An error created when attempting to iterate over a (non-lazy) version of an Range, and the current ruby version does not support #lazy.